Learn R Programming

eglhmm (version 0.1-3)

miscprints: Specialised print methods.

Description

Print objects of class "RhoExpForm", "RhoProbForm" and "kitty", appropriately.

Usage

# S3 method for RhoExpForm
print(x, ...)
# S3 method for RhoProbForm
print(x, ...)
# S3 method for kitty
print(x, ...)

Value

None.

Arguments

x

An object of class "RhoExpForm", "RhoProbForm" or "kitty" respectively.

...

Not used. Present for compatibility with the generic print() function.

Author

Rolf Turner rolfturner@posteo.net

Details

The methods print.RhoExpForm() and print.RhoProbForm() are present essentially for debugging purposes only. The method print.kitty() is present to improve the appearance of printed output from eglhmm when there is a "message" component of this output. None of these methods would normally be called by users.