An object of class c("eglhmm","reordered") which
is identical to the argument x in most respects.
The components which (may) differ are:
The entries of these components will have the same numerical
values as before but, given that the ordering of the states has
actually changed, will have different orderings, corresponding
to the new ordering of the states.
Note that the attribute
preSpecSigma of the
component theta, may differ from what it was in x.
The returned value will also have a component neworder
which is an integer vector providing the indices of the
reordering of the states. It also currently (format(Sys.Date(),"%d/%m/%Y")) has a
component newlog.like. This should (if there is any
justice in the world --- but there isn't!) have the same value
as the component log.like. Once I am confident that
everything is working as it should, the newlog.like
component will be removed.